@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gccv/structs.h 
  *
- * Copyright (C) 2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2008-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -39,6 +39,26 @@ typedef struct {
 	int start, cur;
 } TextSelBounds;
 
+typedef enum {
+	AnchorNorthWest, AnchorNorth, AnchorNorthEast,
+	AnchorLineWest, AnchorLine, AnchorLineEast,
+	AnchorWest, AnchorCenter, AnchorEast,
+	AnchorSouthWest, AnchorSouth, AnchorSouthEast 
+} Anchor;
+
+typedef enum {
+	ArrowHeadNone,
+	ArrowHeadFull,
+	ArrowHeadLeft,
+	ArrowHeadRight,
+} ArrowHeads;
+
+typedef enum {
+	Normalscript,
+	Subscript,
+	Superscript
+} TextPosition;
+
 }
 
 #endif	//	 GCCV_RECTANGLE_H
