@@ -4,7 +4,7 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,9 +24,12 @@
 
 #include "config.h"
 #include "application.h"
+#include "atom.h"
+#include "bond.h"
 #include "document.h"
 #include "electron.h"
 #include "fragment.h"
+#include "gcp-stock-pixbufs.h"
 #include "text.h"
 #include "plugin.h"
 #include "mesomer.h"
@@ -44,19 +47,14 @@
 #include "tool.h"
 #include "tools.h"
 #include "target.h"
+#include "view.h"
 #include "window.h"
 #include "zoomdlg.h"
 #include <gcu/filechooser.h>
 #include <gcu/loader.h>
-#include <gcu/loader-error.h>
+#include <goffice/utils/go-file.h>
 #include <goffice/goffice.h>
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/utils/go-file.h>
-#   include <gio/gio.h>
-#endif
-#ifndef HAVE_GO_CONF_SYNC
-#	include <gconf/gconf-client.h>
-#endif
+#include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 #include <openbabel/mol.h>
 #include <openbabel/reaction.h>
@@ -251,17 +249,10 @@ bool	Application::m_bInit = false;
 bool	Application::m_Have_Ghemical = false;
 bool	Application::m_Have_InChI = false;
 
-#ifdef HAVE_GO_CONF_SYNC
 static void on_config_changed (GOConfNode *node, gchar const *key, Application *app)
 {
 	app->OnConfigChanged (node, key);
 }
-#else
-static void on_config_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry, Application *app)
-{
-	app->OnConfigChanged (client, cnxn_id, entry);
-}
-#endif
 
 Application::Application ():
 	gcu::Application ("GChemPaint", DATADIR, "gchempaint", "gchempaint")
@@ -373,7 +364,6 @@ Application::Application ():
 		found = Loader::GetNextLoader (it);
 	}
 	// test if OpenBabel supports some extra types
-	TestSupportedType ("chemical/x-cml");
 	TestSupportedType ("chemical/x-mdl-molfile");
 	TestSupportedType ("chemical/x-pdb");
 	TestSupportedType ("chemical/x-xyz");
@@ -394,21 +384,13 @@ Application::Application ():
 		}
 	}
 	
-#ifdef HAVE_GO_CONF_SYNC
 	m_ConfNode = go_conf_get_node (GetConfDir (), GCP_CONF_DIR_SETTINGS);
-#else
-	GError *error = NULL;
-	m_ConfClient = gconf_client_get_default ();
-#endif
 	GCU_GCONF_GET ("compression", int, CompressionLevel, 0)
+	GCU_GCONF_GET ("tearable-mendeleiev", bool, TearableMendeleiev, false)
 	bool CopyAsText;
 	GCU_GCONF_GET ("copy-as-text", bool, CopyAsText, false)
 	ClipboardFormats = CopyAsText? GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;
-#ifdef HAVE_GO_CONF_SYNC
 	m_NotificationId = go_conf_add_monitor (m_ConfNode, NULL, (GOConfMonitorFunc) on_config_changed, this);
-#else
-	m_NotificationId = gconf_client_notify_add (m_ConfClient, "/apps/gchemutils/paint/settings", (GConfClientNotifyFunc) on_config_changed, this, NULL, NULL);
-#endif
 	// make themes permanent with this as a dummy client
 	list <string> Names = TheThemeManager.GetThemesNames ();
 	list <string>::iterator j, jend = Names.end ();
@@ -418,6 +400,11 @@ Application::Application ():
 		pTheme = TheThemeManager.GetTheme (*j);
 		pTheme->AddClient (m_Dummy);
 	}
+	// Create cursors
+	GdkPixbuf *unallowed = gdk_pixbuf_new_from_inline (-1, gcp_unallowed, false, NULL);
+	m_Cursors[CursorUnallowed] = gdk_cursor_new_from_pixbuf (gdk_display_get_default (), unallowed, 3, 3);
+	g_object_unref (unallowed);
+	m_Cursors[CursorPencil] = gdk_cursor_new (GDK_PENCIL);
 }
 
 Application::~Application ()
@@ -438,16 +425,13 @@ Application::~Application ()
 		pTheme->RemoveClient (m_Dummy);
 	}
 	delete m_Dummy;
-#ifdef HAVE_GO_CONF_SYNC
 	go_conf_remove_monitor (m_NotificationId);
 	go_conf_free_node (m_ConfNode);
 	m_ConfNode = NULL;
-#else
-	gconf_client_notify_remove (m_ConfClient, m_NotificationId);
-	g_object_unref (m_ConfClient);
-	m_ConfClient = NULL;
-#endif
 	TheThemeManager.Shutdown ();
+	// unref cursors
+	for (int i = 0; i < CursorMax; i++)
+		gdk_cursor_unref (m_Cursors[i]);
 }
 
 void Application::ActivateTool (const string& toolname, bool activate)
@@ -628,7 +612,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				m_pActiveDoc->ExportImage (filename2, pixbuf_type, GetImageResolution ());
 				break;
 			default:
-				if (Save (filename2, mime_type, pDoc));
+				if (Save (filename2, mime_type, pDoc, ContentType2D));
 				else if (!strcmp (mime_type, "application/x-gchempaint"))
 					SaveGcp (filename2, pDoc);
 				else
@@ -636,7 +620,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			}
 		}
 		g_object_unref (file);
-	} else  try { //loading
+	} else  { //loading
 		file = g_file_new_for_uri (filename);
 		err = g_file_query_exists (file, NULL);
 		g_object_unref (file);
@@ -663,8 +647,37 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			pDoc = m_pActiveDoc;
 		}
 		pDoc->SetFileName(filename2, mime_type);
-		if (Load (filename2, mime_type, pDoc)) {
-			pDoc->Loaded ();
+		ContentType type = Load (filename2, mime_type, pDoc);
+		if (type != ContentTypeUnknown) {
+			switch (type) {
+			case ContentType3D: {
+				// open in gchem3d instead
+				string command = string ("gchem3d-") + API_VERSION + " " + filename2;
+				g_spawn_command_line_async (command.c_str (), NULL);
+				if (create) {
+					pDoc->GetWindow ()->Destroy ();
+					pDoc = NULL;
+					} else
+					pDoc->Clear ();
+				return false;
+			}
+			case ContentTypeCrystal:
+				break;
+			case ContentTypeSpectrum:
+				break;
+			default: {
+				double l = pDoc->GetMedianBondLength ();
+				if (l > 0.) {
+					double r = pDoc->GetBondLength () / l;
+					if (fabs (r - 1.) > .1) { // might not work properly in some rare cases when there are a lot of short or long bonds
+						Matrix2D m (r, 0., 0., r);
+						// FIXME: this would not work for reactions
+						pDoc->Transform2D (m, 0., 0.);
+					}
+				}
+				break;
+			}
+			};
 			pDoc->GetView ()->AddObject (pDoc);
 			pDoc->GetView ()->Update (pDoc);
 			pDoc->GetView ()->EnsureSize ();
@@ -672,7 +685,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", pDoc->HasChildren ());
 		} else {
 			if (create) {
-				pDoc->GetWindow ()->Destroy ();;
+				pDoc->GetWindow ()->Destroy ();
 				pDoc = NULL;
 				while (gdk_events_pending ())
 					gtk_main_iteration ();
@@ -683,20 +696,6 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				OpenWithBabel (filename2, mime_type, pDoc);
 		}
 	}
-	catch (LoaderError &e) {
-		pDoc->Clear ();
-		char *unescaped = g_uri_unescape_string (filename, NULL);
-		string mess = _("Error in ");
-		mess += unescaped;
-		// Note to translator: add a space if needed before the semicolon
-		mess += _(":\n");
-		mess += e.what ();
-		GtkWidget *message = gtk_message_dialog_new (NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess.c_str (), NULL, NULL);
-		g_free (unescaped);
-		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
-		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
-		gtk_widget_show (message);
-	}
 	return false;
 }
 
@@ -900,7 +899,6 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 			g_error_free (error);
 			throw 1;
 		}
-		xmlKeepBlanksDefault (1); // to be sure we don't loose significant spaces.
 		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml, 
 				 (xmlInputCloseCallback) g_input_stream_close, input, filename.c_str (), NULL, 0))) {
 			g_object_unref (file);
@@ -1018,7 +1016,7 @@ void Application::Zoom (double zoom)
 	}
 }
 
-static void on_tool_changed (GtkAction *action, GtkAction *current, Application* App)
+static void on_tool_changed (G_GNUC_UNUSED GtkAction *action, GtkAction *current, Application* App)
 {
 	App->OnToolChanged (current);
 }
@@ -1125,8 +1123,8 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 				// set the pixbuf color to the corresponding style for the style
 				unsigned char red, blue, green;
 				red = m_Style->fg[c].red >> 8;
-				green = m_Style->fg[c].green >> 8;
-				blue = m_Style->fg[c].blue >> 8;
+				green = m_Style->fg[c].red >> 8;
+				blue = m_Style->fg[c].red >> 8;
 				unsigned char *line, *cur;
 				line = gdk_pixbuf_get_pixels (icon);
 				int i, j, rows, cols, rowstride;
@@ -1211,18 +1209,15 @@ void Application::ActivateWindowsActionWidget (const char *path, bool activate)
 	}
 }
 
-#ifdef HAVE_GO_CONF_SYNC
 void Application::OnConfigChanged (GOConfNode *node, gchar const *name)
 {
-#else
-void Application::OnConfigChanged (GConfClient *client, guint cnxn_id, GConfEntry *entry)
-{
-	if (client != m_ConfClient)
-		return;	// we might want an error message?
-	if (cnxn_id != m_NotificationId)
-		return;	// we might want an error message?
-#endif
 	GCU_UPDATE_KEY ("compression", int, CompressionLevel, {})
+	GCU_UPDATE_KEY ("tearable-mendeleiev", bool, TearableMendeleiev,
+					{
+						Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
+						if (ToolsBox)
+							ToolsBox->Update ();
+					})
 	bool CopyAsText;
 	GCU_UPDATE_KEY ("copy-as-text", bool, CopyAsText, ClipboardFormats = CopyAsText?GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;)
 }
