@@ -24,22 +24,22 @@
 
 #include "config.h"
 #include "atom.h"
-#include "electron.h"
 #include "bond.h"
+#include "document.h"
+#include "electron.h"
 #include "molecule.h"
 #include "settings.h"
 #include "theme.h"
 #include "view.h"
-#include "document.h"
+#include "widgetdata.h"
 #include "Hposdlg.h"
-#include <canvas/gcp-canvas-group.h>
-#include <canvas/gcp-canvas-rect-ellipse.h>
-#include <canvas/gcp-canvas-bpath.h>
-#include <canvas/gcp-canvas-pango.h>
+#include <gccv/canvas.h>
+#include <gccv/circle.h>
+#include <gccv/group.h>
+#include <gccv/text.h>
+#include <gccv/text-tag.h>
 #include <gcu/element.h>
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/math/go-math.h>
-#endif
+#include <goffice/math/go-math.h>
 #include <openbabel/mol.h>
 #include <glib/gi18n-lib.h>
 #include <cstdlib>
@@ -53,7 +53,9 @@ using namespace std;
 
 namespace gcp {
 
-Atom::Atom (): gcu::Atom (),
+Atom::Atom ():
+	gcu::Atom (),
+	ItemClient (),
 	m_ShowSymbol (false),
 	m_HPosStyle (AUTO_HPOS)
 {
@@ -88,7 +90,7 @@ Atom::~Atom ()
 		pView->Remove (electron);
 		electron->SetParent (NULL); // avoids a call to RemoveElectron()
 		delete electron;
-		electron = GetFirstChild (i);
+		electron = GetNextChild (i);
 	}
 	if (m_Layout)
 		g_object_unref (G_OBJECT (m_Layout));
@@ -96,7 +98,9 @@ Atom::~Atom ()
 		g_object_unref (G_OBJECT (m_ChargeLayout));
 }
 
-Atom::Atom (int Z, double x, double y, double z): gcu::Atom (Z, x, y, z),
+Atom::Atom (int Z, double x, double y, double z):
+	gcu::Atom (Z, x, y, z),
+	ItemClient (),
 	m_ShowSymbol (false),
 	m_HPosStyle (AUTO_HPOS)
 {
@@ -118,7 +122,9 @@ Atom::Atom (int Z, double x, double y, double z): gcu::Atom (Z, x, y, z),
 	m_SWidth = 0.;
 }
 
-Atom::Atom (OBAtom* atom): gcu::Atom (),
+Atom::Atom (OBAtom* atom):
+	gcu::Atom (),
+	ItemClient (),
 	m_ShowSymbol (false),
 	m_HPosStyle (AUTO_HPOS)
 {
@@ -331,7 +337,7 @@ void Atom::Update ()
 			static_cast<Bond*> ((*j).second)->SetDirty ();
 }
 
-void Atom::Add (GtkWidget* w) const
+/*void Atom::Add (GtkWidget* w) const
 {
 	if (!w || !GetZ ())
 		return;
@@ -343,14 +349,12 @@ void Atom::Add (GtkWidget* w) const
 	View* pView = pData->m_View;
 	Theme *pTheme = pView->GetDoc ()->GetTheme ();
 	if (m_Layout == NULL) {
-		PangoContext* pc = pView->GetPangoContext ();
+		PangoContext *pc = gccv::Text::GetContext ();
 		const_cast <Atom *> (this)->m_Layout = pango_layout_new (pc);
 		const_cast <Atom *> (this)->m_HLayout = pango_layout_new (pc);
 	}
 	if (m_FontName != pView->GetFontName ()) {
-		const_cast <Atom *> (this)->m_FontName = pView->GetFontName ();
 		pango_layout_set_font_description (m_Layout, pView->GetPangoFontDesc ());
-		pango_layout_set_font_description (m_HLayout, pView->GetPangoFontDesc ());
 		pango_layout_set_text (m_Layout, "l", 1);
 		PangoLayoutIter* iter = pango_layout_get_iter (m_Layout);
 		const_cast <Atom *> (this)->m_ascent = pango_layout_iter_get_baseline (iter) / PANGO_SCALE;
@@ -482,18 +486,16 @@ void Atom::Add (GtkWidget* w) const
 		g_object_set_data (G_OBJECT (group), "symbol", item);
 		g_object_set_data (G_OBJECT (item), "object", (void *) this);
 		g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
-		if (GetAttachedHydrogens ()) {
-			item = gnome_canvas_item_new (
-								group,
-								gnome_canvas_pango_get_type (),
-								"x", x - m_lbearing + m_xHOffs,
-								"y", y - m_ascent + m_CHeight + m_yHOffs,
-								"layout", m_HLayout,
-							NULL);
-			g_object_set_data (G_OBJECT (group), "hydrogens", item);
-			g_object_set_data (G_OBJECT (item), "object", (void *) this);
-			g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
-		}
+		item = gnome_canvas_item_new (
+							group,
+							gnome_canvas_pango_get_type (),
+							"x", x - m_lbearing + m_xHOffs,
+							"y", y - m_ascent + m_CHeight + m_yHOffs,
+							"layout", m_HLayout,
+						NULL);
+		g_object_set_data (G_OBJECT (group), "hydrogens", item);
+		g_object_set_data (G_OBJECT (item), "object", (void *) this);
+		g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
 	} else {
 		item = gnome_canvas_item_new (
 								group,
@@ -528,9 +530,9 @@ void Atom::Add (GtkWidget* w) const
 	}
 	pData->Items[this] = group;
 	const_cast <Atom *> (this)->m_width /= pTheme->GetZoomFactor ();
-	const_cast <Atom *> (this)->m_height /= pTheme->GetZoomFactor ();
+	const_cast <Atom *> (this)->m_height /= pTheme->GetZoomFactor ();*/
 	/* add charge */
-	int charge = GetCharge ();
+/*	int charge = GetCharge ();
 	if (charge) {
 		int align = const_cast <Atom *> (this)->GetChargePosition (const_cast <Atom *> (this)->m_ChargePos, m_ChargeAngle * 180 / M_PI, x, y);
 		if (m_ChargeDist != 0.) {
@@ -545,7 +547,7 @@ void Atom::Add (GtkWidget* w) const
 			fig = g_strdup_printf ("%d", abs (charge));
 			PangoRectangle rect;
 			if (!m_ChargeLayout) {
-				PangoContext* pc = pData->m_View->GetPangoContext();
+				PangoContext* pc = gccv::Text::GetContext();
 				const_cast <Atom *> (this)->m_ChargeLayout = pango_layout_new (pc);
 				pango_layout_set_font_description (m_ChargeLayout, pData->m_View->GetPangoSmallFontDesc ());
 			}
@@ -642,9 +644,9 @@ void Atom::Add (GtkWidget* w) const
 		electron->Add (w);
 		electron = GetNextChild (i);
 	}
-}
+}*/
 
-void Atom::Update (GtkWidget* w) const
+/*void Atom::Update (GtkWidget* w) const
 {
 	if (!w || !GetZ ())
 		return;
@@ -659,7 +661,7 @@ void Atom::Update (GtkWidget* w) const
 	GnomeCanvasGroup *group = pData->Items[this];
 	if (m_FontName != pData->m_View->GetFontName ()) {
 		View *pView = pData->m_View;
-		PangoContext* pc = pView->GetPangoContext ();
+		PangoContext* pc = gccv::Text::GetContext ();
 		PangoLayout *Layout = pango_layout_new (pc);
 		pango_layout_set_font_description (Layout, pView->GetPangoFontDesc ());
 		pango_layout_set_font_description (m_Layout, pView->GetPangoFontDesc ());
@@ -729,7 +731,7 @@ void Atom::Update (GtkWidget* w) const
 				fig = g_strdup_printf ("%d", abs (charge));
 				PangoRectangle rect;
 				if (!m_ChargeLayout) {
-					PangoContext* pc = pData->m_View->GetPangoContext ();
+					PangoContext* pc = gccv::Text::GetContext ();
 					const_cast <Atom *> (this)->m_ChargeLayout = pango_layout_new (pc);
 					pango_layout_set_font_description (m_ChargeLayout, pData->m_View->GetPangoSmallFontDesc ());
 				}
@@ -824,7 +826,7 @@ void Atom::Update (GtkWidget* w) const
 			if 	(abs (charge) > 1) {
 				fig = g_strdup_printf ("%d", abs (charge));
 				if (!m_ChargeLayout) {
-					PangoContext* pc = pData->m_View->GetPangoContext ();
+					PangoContext* pc = gccv::Text::GetContext ();
 					const_cast <Atom *> (this)->m_ChargeLayout = pango_layout_new (pc);
 					pango_layout_set_font_description (m_ChargeLayout, pData->m_View->GetPangoSmallFontDesc ());
 				}
@@ -930,7 +932,7 @@ void Atom::Update (GtkWidget* w) const
 		electron->Update (w);
 		electron = GetNextChild (i);
 	}
-}
+}*/
 
 void Atom::UpdateAvailablePositions ()
 {
@@ -1229,50 +1231,39 @@ bool Atom::LoadNode (xmlNodePtr)
 	return true;
 }
 
-void Atom::SetSelected (GtkWidget* w, int state)
+void Atom::SetSelected (int state)
 {
-	WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (w), "data");
-	GnomeCanvasGroup* group = pData->Items[this];
-	gpointer item;
-	gchar const *color, *chargecolor;
-	bool visible = true;
+	GOColor textcolor, othercolor;
 	
 	switch (state) {	
+	default:
 	case SelStateUnselected:
-		color = NULL;
-		chargecolor = "black";
-			visible = false;
+		textcolor = 0;
+		othercolor = RGBA_BLACK;
 		break;
 	case SelStateSelected:
-		chargecolor = color = SelectColor;
+		othercolor = textcolor = SelectColor;
 		break;
 	case SelStateUpdating:
-		chargecolor = color = AddColor;
+		othercolor = textcolor = AddColor;
 		break;
 	case SelStateErasing:
-		chargecolor = color = DeleteColor;
-		break;
-	default:
-		color = NULL;
-		chargecolor = "black";
+		othercolor = textcolor = DeleteColor;
 		break;
 	}
-	item = g_object_get_data (G_OBJECT (group), "rect");
-	g_object_set (G_OBJECT (item),
-				"fill_color", color, NULL);
-	if (visible)
-		gnome_canvas_item_show (GNOME_CANVAS_ITEM (item));
-	else
-		gnome_canvas_item_hide (GNOME_CANVAS_ITEM (item));
-	if ((item = g_object_get_data (G_OBJECT (group), "bullet")))
-		g_object_set (item, "fill_color", chargecolor, NULL);
-	if ((item = g_object_get_data (G_OBJECT (group), "figure")))
-		g_object_set (item, "fill_color", chargecolor, NULL);
-	if ((item = g_object_get_data (G_OBJECT (group), "circle")))
-		g_object_set (item, "outline_color", chargecolor, NULL);
-	if ((item = g_object_get_data (G_OBJECT (group), "sign")))
-		g_object_set (item, "outline_color", chargecolor, NULL);
-	Object::SetSelected (w, state);
+	gccv::Group *group = static_cast <gccv::Group *> (m_Item);
+	std::list<gccv::Item *>::iterator it;
+	gccv::Item *item = group->GetFirstChild (it);
+	while (item) {
+		gccv::FillItem *fill;
+		if ((fill = dynamic_cast <gccv::Rectangle *> (item)))
+			fill->SetFillColor (textcolor);
+		else if ((fill = dynamic_cast <gccv::FillItem *> (item)))
+			fill->SetFillColor (othercolor);
+		else
+			static_cast <gccv::LineItem *> (item)->SetLineColor (othercolor);
+		item = group->GetNextChild (it);
+	}
 }
 
 bool Atom::AcceptNewBonds (int nb)
@@ -1299,7 +1290,7 @@ void Atom::AddToMolecule (Molecule* Mol)
 	Mol->AddAtom (this);
 }
 
-void Atom::BuildItems (WidgetData* pData)
+/*void Atom::BuildItems (WidgetData* pData)
 {
 	GnomeCanvasGroup* group = pData->Items[this];
 	void* item;
@@ -1494,7 +1485,7 @@ void Atom::BuildItems (WidgetData* pData)
 	m_height /= pTheme->GetZoomFactor ();
 	if (m_Changed > 0)
 		m_Changed--;
-}
+}*/
 	
 double Atom::GetYAlign ()
 {
@@ -1672,24 +1663,8 @@ xmlNodePtr Atom::Save (xmlDocPtr xml) const
 		xmlNewProp (node, (xmlChar*) "show-symbol", (xmlChar*) "true");
 	}
 	if (m_HPosStyle != AUTO_HPOS) {
-		char const *pos;
-		switch (m_HPosStyle) {
-		default:
-		case RIGHT_HPOS:
-			pos = "right";
-			break;
-		case LEFT_HPOS:
-			pos = "left";
-			break;
-		case TOP_HPOS:
-			pos = "top";
-			break;
-		case BOTTOM_HPOS:
-			pos = "bottom";
-			break;
-		}
-		xmlNewProp (node, reinterpret_cast <xmlChar const*> ("H-position"),
-					reinterpret_cast <xmlChar const*> (pos));
+		xmlNewProp (node, (xmlChar*) "H-position",
+					(xmlChar*) ((m_HPosStyle == LEFT_HPOS)? "left": "right"));
 	}
 	return node;
 }
@@ -1771,12 +1746,6 @@ bool Atom::Load (xmlNodePtr node)
 			m_HPosStyle = LEFT_HPOS;
 		else if (!strcmp (buf, "right"))
 			m_HPosStyle = RIGHT_HPOS;
-		else if (!strcmp (buf, "top"))
-			m_HPosStyle = TOP_HPOS;
-		else if (!strcmp (buf, "bottom"))
-			m_HPosStyle = BOTTOM_HPOS;
-		else // who know?
-			m_HPosStyle = AUTO_HPOS;
 		xmlFree (buf);
 		Update ();
 	}
@@ -1948,5 +1917,155 @@ void Atom::BuildSymbolGeometry (double width, double height, double ascent)
 	m_SAngleL = atan2 (m_SHeightL, m_SWidth);
 }
 
+void Atom::AddItem ()
+{
+	if (m_Item)
+		return;
+	Document *doc = static_cast <Document*> (GetDocument ());
+	View *view = doc->GetView ();
+	Theme *theme = doc->GetTheme ();
+	double x, y;
+	GetCoords (&x, &y);
+	x *= theme->GetZoomFactor ();
+	y *= theme->GetZoomFactor ();
+	// always use a group, even if not needed
+	gccv::Group *group = new gccv::Group (view->GetCanvas ()->GetRoot (), x, y, this);
+	if ((GetZ() != 6) || (GetBondsNumber() == 0) || m_ShowSymbol) {
+		gccv::Text *text = new gccv::Text (group, 0., 0., this);
+		text->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: 0);
+		text->SetPadding (theme->GetPadding ());
+		text->SetLineColor (0);
+		text->SetLineWidth (0.);
+		text->SetFontDescription (view->GetPangoFontDesc ());
+		text->SetText (GetSymbol ());
+		text->SetLineOffset (view->GetCHeight ());
+		// build the symbol geometry
+		BuildSymbolGeometry (text->GetWidth (), text->GetHeight (), text->GetAscent () - text->GetY () - view->GetCHeight ());		
+		int n = GetAttachedHydrogens ();
+		gccv::Rect ink, logical;
+		text->GetBounds (&ink, &logical);
+		m_width = (logical.x1 - logical.x0 + 2 * theme->GetPadding ()) / theme->GetZoomFactor ();
+		m_height = (logical.y1 - logical.y0 + 2 * theme->GetPadding ()) / theme->GetZoomFactor ();
+		if (n > 0) {
+			string hs = "H";
+			if (n > 1) {
+				char *str = g_strdup_printf ("%d", n);
+				hs += str;
+				g_free (str);
+			}
+			text = new gccv::Text (group, 0., 0., this);
+			text->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: 0);
+			text->SetPadding (theme->GetPadding ());
+			text->SetLineColor (0);
+			text->SetLineWidth (0.);
+			text->SetFontDescription (view->GetPangoFontDesc ());
+			text->SetText (hs.c_str ());
+			if (n >1) {
+				gccv::TextTag *tag = new gccv::PositionTextTag (gccv::Subscript, text->GetDefaultFontSize ());
+				tag->SetStartIndex (1);
+				tag->SetEndIndex (hs.length ());
+				text->InsertTextTag (tag);
+			}
+			text->SetLineOffset (view->GetCHeight ());
+			switch (m_HPos) {
+			case LEFT_HPOS:
+				text->SetAnchor (gccv::AnchorLineEast);
+				text->SetPosition (logical.x0, 0.);
+				break;
+			case RIGHT_HPOS:
+				text->SetAnchor (gccv::AnchorLineWest);
+				text->SetPosition (logical.x1, 0.);
+				break;
+			case TOP_HPOS:
+				text->SetAnchor (gccv::AnchorLineWest);
+				text->SetPosition (-view->GetHWidth (), ink.y0 - ink.y1 - 2.); // 2. is arbitrary
+				break;
+			case BOTTOM_HPOS:
+				text->SetAnchor (gccv::AnchorLineWest);
+				text->SetPosition (-view->GetHWidth (), ink.y1 - ink.y0 + 2.);
+				break;
+			default:
+				g_critical ("This should not happen, please file a bug report");
+				break;
+			}
+/*			pango_layout_set_text (m_HLayout, "H", -1);
+			pango_layout_get_extents (m_HLayout, &HRect, NULL);
+			switch (m_HPos) {
+			case LEFT_HPOS:
+				//the x offset needs to be calculated after adding possible stoichimoetry.
+				m_xHOffs = m_yHOffs = 0.;
+				break;
+			case RIGHT_HPOS:
+				m_xHOffs = rect.width / PANGO_SCALE + 1.;
+				m_yHOffs = 0.;
+				break;
+			case TOP_HPOS:
+				m_xHOffs = m_lbearing - pTheme->GetPadding () - HRect.width / PANGO_SCALE / 2.;
+				break;
+			case BOTTOM_HPOS:
+				m_xHOffs = m_lbearing - pTheme->GetPadding () - HRect.width / PANGO_SCALE / 2.;
+				m_yHOffs = m_CHeight * 2. + pTheme->GetPadding ();
+				break;
+			default:
+				g_critical ("This should not happen, please file a bug report");
+				break;
+			}
+			if (n > 1) {
+				gchar const *nb =  g_strdup_printf ("%d", n);
+				int nw = strlen (nb);
+				PangoAttrList *pal = pango_attr_list_new ();
+				text = g_strconcat ("H", nb, NULL);
+				pango_layout_set_text (m_HLayout, text, -1);
+				nw = strlen (text);
+				PangoAttribute *attr = pango_attr_font_desc_new (pView->GetPangoSmallFontDesc());
+				attr->start_index = 1;
+				attr->end_index = strlen (text);
+				pango_attr_list_insert (pal, attr);
+				attr = pango_attr_rise_new (-2 * PANGO_SCALE);
+				attr->start_index = 1;
+				attr->end_index = nw;
+				pango_attr_list_insert (pal, attr);
+				pango_layout_set_attributes (m_HLayout, pal);
+				pango_attr_list_unref (pal);
+			}
+			pango_layout_get_extents (m_HLayout, &HRect, NULL);
+			// evaluate underlying rectangle size and position
+			if (HRect.width > 0) {
+				switch (m_HPos) {
+				case LEFT_HPOS:
+					m_xHOffs = -HRect.width / PANGO_SCALE - 1.;
+					m_xROffs = m_xHOffs;
+					m_length += HRect.width / PANGO_SCALE + 1.;
+					break;
+				case RIGHT_HPOS:
+					m_length += HRect.width / PANGO_SCALE + 1.;
+					break;
+				case TOP_HPOS:
+					m_yHOffs = -HRect.height / PANGO_SCALE - pTheme->GetPadding ();
+					m_yROffs = -HRect.height / PANGO_SCALE - pTheme->GetPadding ();
+					m_text_height += HRect.height / PANGO_SCALE + pTheme->GetPadding ();
+					m_length = MAX (m_length, HRect.width / PANGO_SCALE);
+					break;
+				case BOTTOM_HPOS:
+					m_text_height += HRect.height / PANGO_SCALE + pTheme->GetPadding ();
+					m_length = MAX (m_length, HRect.width / PANGO_SCALE);
+					break;
+				default:
+					break;
+				}
+			}*/
+		}
+	} else {
+		gccv::FillItem *fill = new gccv::Rectangle (group,  -3., -3., 6., 6., this);
+		fill->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: 0);
+		fill->SetLineColor (0);
+		if (m_DrawCircle) {
+			fill = new gccv::Circle ( group, 0., 0., theme->GetStereoBondWidth () / 2., this);
+			fill->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: Color);
+			fill->SetLineColor (0);
+		}
+	}
+	m_Item = group;
+}
 
 }	//	namespace gcp
