@@ -45,7 +45,7 @@ static void on_title_changed (GtkEntry *entry, DocPropDlg *dlg)
 	dlg->OnTitleChanged (gtk_entry_get_text (entry));
 }
 
-static bool on_title_focused_out (GtkEntry *entry, GdkEventFocus *event, DocPropDlg *dlg)
+static bool on_title_focused_out (GtkEntry *entry, G_GNUC_UNUSED GdkEventFocus *event, DocPropDlg *dlg)
 {
 	dlg->OnTitleChanged (gtk_entry_get_text (entry));
 	return false;
@@ -56,7 +56,7 @@ static void on_name_changed (GtkEntry *entry, DocPropDlg *dlg)
 	dlg->OnNameChanged (gtk_entry_get_text (entry));
 }
 
-static bool on_name_focused_out (GtkEntry *entry, GdkEventFocus *event, DocPropDlg *dlg)
+static bool on_name_focused_out (GtkEntry *entry, G_GNUC_UNUSED GdkEventFocus *event, DocPropDlg *dlg)
 {
 	dlg->OnNameChanged (gtk_entry_get_text (entry));
 	return false;
@@ -67,7 +67,7 @@ static void on_mail_changed (GtkEntry *entry, DocPropDlg *dlg)
 	dlg->OnMailChanged (gtk_entry_get_text (entry));
 }
 
-static bool on_mail_focused_out (GtkEntry *entry, GdkEventFocus *event, DocPropDlg *dlg)
+static bool on_mail_focused_out (GtkEntry *entry, G_GNUC_UNUSED GdkEventFocus *event, DocPropDlg *dlg)
 {
 	dlg->OnMailChanged (gtk_entry_get_text (entry));
 	return false;
@@ -157,14 +157,6 @@ DocPropDlg::DocPropDlg (Document* pDoc):
 	
 DocPropDlg::~DocPropDlg ()
 {
-	list <string> names = TheThemeManager.GetThemesNames ();
-	list <string>::iterator i, end = names.end ();
-	Theme *theme;
-	for (i = names.begin (); i != end; i++) {
-		theme = TheThemeManager.GetTheme (*i);
-		if (theme)
-			theme->RemoveClient (this);
-	}
 }
 
 void DocPropDlg::OnThemeNamesChanged ()
