@@ -417,7 +417,7 @@ void Document::ExportOB () const
 	}
 }
 
-void Document::DoPrint (GtkPrintOperation *print, GtkPrintContext *context) const
+void Document::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext *context, G_GNUC_UNUSED int page) const
 {
 	cairo_t *cr;
 	double width, height, x, y, w, h;
@@ -613,6 +613,8 @@ void Document::Save () const
 	setlocale (LC_TIME, "C");
 
 	try {
+		if (m_pApp && m_pApp->Save (m_filename, m_FileType.c_str (), this, ContentType2D))
+			return;
 		if (m_FileType != "application/x-gchempaint")
 			ExportOB ();
 		else {
@@ -1330,7 +1332,7 @@ void Document::SetTheme (Theme *theme)
 		m_pView->UpdateTheme ();
 }
 
-bool Document::OnSignal (SignalId Signal, Object *Child)
+bool Document::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Child)
 {
 	if (Signal == OnThemeChangedSignal) {
 		m_BondLength = m_Theme->GetBondLength ();
@@ -1445,7 +1447,7 @@ bool Document::SetProperty (unsigned property, char const *value)
 		double length = strtod (value, &end);
 		if (*end != 0)
 			return false;
-		gcu::Document::m_Scale = m_Theme->GetBondLength () / length; 
+		gcu::Document::SetScale (m_Theme->GetBondLength () / length); 
 	}
 	}
 	return true;
