@@ -28,10 +28,8 @@
 #include "view.h"
 #include "window.h"
 #include <gcu/filechooser.h>
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/utils/go-image.h>
-#   include <gio/gio.h>
-#endif
+#include <goffice/utils/go-image.h>
+#include <gio/gio.h>
 #include <glib/gi18n.h>
 #include <clocale>
 #include <map>
@@ -72,7 +70,7 @@ void gsvApplication::OnQuit ()
 	}
 }
 
-bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, GtkWindow *window, Document *Doc)
+bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, G_GNUC_UNUSED GtkWindow *window, Document *Doc)
 {
 	gsvDocument *pDoc = dynamic_cast <gsvDocument *> (Doc);
 	if(bSave) {
